@@ -23,6 +23,7 @@ class GraphWeatherForecaster(torch.nn.Module, PyTorchModelHubMixin):
         hidden_dim_decoder=128,
         hidden_layers_decoder=2,
         norm_type="LayerNorm",
+        device="cpu"
     ):
         """
         Graph Weather Model based off https://arxiv.org/pdf/2202.07575.pdf
@@ -45,7 +46,7 @@ class GraphWeatherForecaster(torch.nn.Module, PyTorchModelHubMixin):
                 one of 'LayerNorm', 'GraphNorm', 'InstanceNorm', 'BatchNorm', 'MessageNorm', or None
         """
         super().__init__()
-
+        self.device = device
         self.encoder = Encoder(
             lat_lons=lat_lons,
             resolution=resolution,
@@ -57,7 +58,8 @@ class GraphWeatherForecaster(torch.nn.Module, PyTorchModelHubMixin):
             hidden_dim_processor_node=hidden_dim_processor_node,
             hidden_layers_processor_edge=hidden_layers_processor_edge,
             mlp_norm_type=norm_type,
-        )
+            device=device
+        ).to(device)
         self.processor = Processor(
             input_dim=node_dim,
             edge_dim=edge_dim,
@@ -67,7 +69,7 @@ class GraphWeatherForecaster(torch.nn.Module, PyTorchModelHubMixin):
             hidden_dim_processor_node=hidden_dim_processor_node,
             hidden_layers_processor_edge=hidden_layers_processor_edge,
             mlp_norm_type=norm_type,
-        )
+        ).to(device)
         self.decoder = Decoder(
             lat_lons=lat_lons,
             resolution=resolution,
@@ -81,19 +83,20 @@ class GraphWeatherForecaster(torch.nn.Module, PyTorchModelHubMixin):
             mlp_norm_type=norm_type,
             hidden_dim_decoder=hidden_dim_decoder,
             hidden_layers_decoder=hidden_layers_decoder,
-        )
+            device=device
+        ).to(device)
 
     def forward(self, features: torch.Tensor) -> torch.Tensor:
         """
         Compute the new state of the forecast
 
         Args:
-            features: The input features, aligned with the order of lat_lons
+            features: The input features, aligned with the order of lat_lons_heights
 
         Returns:
             The next state in the forecast
         """
         x, edge_idx, edge_attr = self.encoder(features)
         x = self.processor(x, edge_idx, edge_attr)
-        x = self.decoder(x, features)
+        x = self.decoder(x, features.shape[0])
         return x
